#! /usr/bin/python3
# -*- coding: utf-8 -*-
from gi.repository import Unity
from unittest import TestCase
import imp

class ResultSet(Unity.ResultSet):
    def __init__(self):
        Unity.ResultSet.__init__(self)
        self.results = []

    def do_add_result(self, result):
        self.results.append({'uri':result.uri,
                             'title':result.title,
                             'comment':result.comment,
                             'icon':result.icon_hint})

class ScopeTestCase(TestCase):
    def init_scope(self, scope_path):
        self.scope_module = imp.load_source('scope', scope_path)
        self.scope = self.scope_module.load_scope()

    def perform_query(self, query, filter_set = Unity.FilterSet.new()):
        result_set = ResultSet()
        ctx = Unity.SearchContext.create(query, 0, filter_set,
                                         None, result_set, None)
        s = self.scope.create_search_for_query(ctx)
        s.run()
        return result_set


class TestEbay(ScopeTestCase):
    def setUp(self):
        self.init_scope('src/unity_ebay_daemon.py')

    def tearDown(self):
        self.scope = None
        self.scope_module = None

    def test_questions_search(self):
        self.scope_module.SEARCH_URI = 'file:tests/data/mock_ebay_pass#%s%s'
        expected_results = ['Apple iPhone 3G - 8GB - Black (AT&T) Smartphone bundle & Charger Original box',
                            'http://www.ebay.com/itm/Apple-iPhone-3G-8GB-Black-AT-T-Smartphone-bundle-Charger-Original-box-/321062088117?pt=Cell_Phones',
                            'Apple iPhone 3G 8GB (A1241) (AT&T) 3.1.3 - Black!!!',
                            'http://www.ebay.com/itm/Apple-iPhone-3G-8GB-A1241-AT-T-3-1-3-Black-/310576662131?pt=Cell_Phones']

        results = []
        for s in ['iphone']:
            result_set = self.perform_query(s)
            results.append(result_set.results[0]['title'])
            results.append(result_set.results[0]['uri'])
            results.append(result_set.results[1]['title'])
            results.append(result_set.results[1]['uri'])
        self.assertEqual(results, expected_results)

    def test_failing_search(self):
        self.scope_module.SEARCH_URI = 'file:tests/data/mock_ebay_fail#'
        for s in ['iphone']:
            result_set = self.perform_query(s)
            print(result_set)
            self.assertEqual(len(result_set.results), 0)

if __name__ == '__main__':
    unittest.main()
